@@ -1,5 +1,4 @@
 import subprocess
-from subprocess import STDOUT, PIPE
 
 from math import isnan
 from math import log as ln
@@ -14,8 +13,12 @@ from av1an.commandtypes import CommandPair, Command
 from av1an.project import Project
 from av1an.chunk import Chunk
 from av1an.manager.Pipes import process_pipe
-import matplotlib
-from matplotlib import pyplot as plt
+try:
+    import matplotlib
+    from matplotlib import pyplot as plt
+except ImportError:
+    matplotlib = None
+    plt = None
 
 # TODO: rework to class, account for dark scenes/banding
 
@@ -156,8 +159,8 @@ def probe_cmd(chunk: Chunk, q, ffmpeg_pipe, encoder, probing_rate) -> CommandPai
     probe_name = gen_probes_names(chunk, q).with_suffix('.ivf').as_posix()
 
     if encoder == 'aom':
-        params = ['aomenc', '--passes=1', '--threads=24',
-                  '--end-usage=q', '--cpu-used=6', '--tile-columns=2', '--tile-rows=1', f'--cq-level={q}']
+        params = ['aomenc', '--passes=1', '--threads=12',
+                  '--end-usage=q', '-b', '8', '--cpu-used=6', f'--cq-level={q}']
         cmd = CommandPair(pipe, [*params, '-o', probe_name, '-'])
 
     elif encoder == 'x265':
@@ -202,10 +205,20 @@ def gen_probes_names(chunk: Chunk, q):
 
 
 def make_pipes(ffmpeg_gen_cmd: Command, command: CommandPair):
-    ffmpeg_gen_pipe = subprocess.Popen(ffmpeg_gen_cmd, stdout=PIPE, stderr=STDOUT)
-    ffmpeg_pipe = subprocess.Popen(command[0], stdin=ffmpeg_gen_pipe.stdout, stdout=PIPE, stderr=STDOUT)
-    pipe = subprocess.Popen(command[1], stdin=ffmpeg_pipe.stdout, stdout=PIPE,
-                            stderr=STDOUT,
+
+    ffmpeg_gen_pipe = subprocess.Popen(ffmpeg_gen_cmd,
+                                        stdout=subprocess.PIPE,
+                                        stderr=subprocess.STDOUT)
+
+    ffmpeg_pipe = subprocess.Popen(command[0],
+                                    stdin=ffmpeg_gen_pipe.stdout,
+                                    stdout=subprocess.PIPE,
+                                    stderr=subprocess.STDOUT)
+
+    pipe = subprocess.Popen(command[1],
+                            stdin=ffmpeg_pipe.stdout,
+                            stdout=subprocess.PIPE,
+                            stderr=subprocess.STDOUT,
                             universal_newlines=True)
 
     return pipe
@@ -261,6 +274,9 @@ def interpolate_data(vmaf_cq: list, target_quality):
 
 
 def plot_probes(project, vmaf_cq, chunk: Chunk, frames):
+    if plt is None:
+        log(f'Matplotlib is not installed or could not be loaded. Unable to plot probes.')
+        return
     # Saving plot of vmaf calculation
 
     x = [x[1] for x in sorted(vmaf_cq)]
